@@ -10,6 +10,7 @@ import numpy as _np
 import torch as _torch
 import torch.distributed as _dist
 import torch.utils.data as _data
+from sklearn.model_selection import KFold as _KFold
 from torch.utils.data import DataLoader as _DataLoader, Dataset as _Dataset
 from torch.utils.data._utils.collate import default_collate as _default_collate
 
@@ -233,6 +234,37 @@ class ETDataHandle:
         return all_d
 
 
+class KfoldDataHandle(ETDataHandle):
+    """Use this when needed to run k-fold(train,test one each fold) on directly passed Dataset from dataloader_args"""
+
+    def create_splits(self, dataspec, out_dir):
+        if self.args.get('num_folds') is None:
+            super(KfoldDataHandle, self).create_splits(dataspec, out_dir)
+        else:
+            dataspec['split_dir'] = out_dir + _os.sep + 'splits'
+            _os.makedirs(dataspec['split_dir'], exist_ok=True)
+            kf = _KFold(self.args['num_folds'])
+            for i, (train_ix, test_ix) in enumerate(kf.split(self.dataloader_args['train']['dataset'])):
+                with open(dataspec['split_dir'] + _os.sep + f'experiment{i}.json', 'w') as sp:
+                    sp.write(_json.dumps({'train': train_ix.tolist(), 'test': test_ix.tolist()}))
+
+    def get_test_dataset(self, split_file, dataspec: dict, dataset_cls=None):
+        if self.args.get('num_folds') is None:
+            return super(KfoldDataHandle, self).get_test_dataset(split_file, dataspec, dataset_cls)
+        else:
+            with open(dataspec['split_dir'] + _os.sep + split_file) as file:
+                test_ix = _json.loads(file.read()).get('test', [])
+                return _data.Subset(self.dataloader_args['train']['dataset'], test_ix)
+
+    def get_train_dataset(self, split_file, dataspec: dict, dataset_cls=None):
+        if self.args.get('num_folds') is None:
+            return super(KfoldDataHandle, self).get_train_dataset(split_file, dataspec, dataset_cls)
+        else:
+            with open(dataspec['split_dir'] + _os.sep + split_file) as file:
+                train_ix = _json.loads(file.read()).get('train', [])
+                return _data.Subset(self.dataloader_args['train']['dataset'], train_ix)
+
+
 class ETDataset(_Dataset):
     def __init__(self, mode='init', limit=None, **kw):
         self.mode = mode
